@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::GenerateFile::FromShareDir; # git description: v0.007-5-g8c7153d
-# ABSTRACT: Create files in the repository or build, based on a template located in a dist sharedir
+package Dist::Zilla::Plugin::GenerateFile::FromShareDir; # git description: v0.008-3-g0a084ed
+# ABSTRACT: Create files in the repository or in the build, based on a template located in a dist sharedir
 # KEYWORDS: plugin distribution generate create file sharedir template
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 use Moose;
 with (
@@ -199,11 +199,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::GenerateFile::FromShareDir - Create files in the repository or build, based on a template located in a dist sharedir
+Dist::Zilla::Plugin::GenerateFile::FromShareDir - Create files in the repository or in the build, based on a template located in a dist sharedir
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -311,7 +311,7 @@ There is also a mailing list available for users of this distribution, at
 L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-irc://irc.perl.org/#distzilla.
+L<irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
